﻿Imports System.Diagnostics
Imports System.Windows.Forms

Public Class Explorer1

    Private Sub Explorer1_Load(ByVal sender As Object,
                               ByVal e As System.EventArgs) Handles Me.Load
        Dim mydocument As String =
            Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments)
        'UI を設定します
        SetUpListViewColumns()
        Call LoadTree(mydocument,
                      Me.TreeView.Nodes.Add(mydocument).Nodes)
    End Sub

    Private Sub LoadTree(ByVal folder As String,
                         ByVal node As TreeNodeCollection)

        Try
            For Each directory As String In System.IO.Directory.GetDirectories(folder)
                Dim tvNode As TreeNode = node.Add(directory.Substring(folder.Length + 1))
                Call LoadTree(directory, tvNode.Nodes)
            Next
        Catch ex As Exception
        End Try
    End Sub

    Private Sub LoadListView(ByVal folder As String)
        Dim lvItem As ListViewItem
        ListView.Items.Clear()
        Try
            For Each file As String In System.IO.Directory.GetFiles(folder)
                lvItem = ListView.Items.Add(System.IO.Path.GetFileName(file))
                lvItem.ImageKey = "Graph1"
                lvItem.SubItems.AddRange(New String() {"列2", "列3"})
            Next
        Catch ex As Exception
        End Try
    End Sub

    Private Sub SetUpListViewColumns()

        ' TODO: listview 列を設定するコードを追加します
        Dim lvColumnHeader As ColumnHeader

        ' 列幅の設定は現在のビューにのみ適用されます。したがってこの行は、
        '  ListView で SmallIcon ビューを表示してから
        '  列幅を設定することを明示的に設定するものです
        SetView(View.SmallIcon)

        lvColumnHeader = ListView.Columns.Add("列1")
        ' SmallIcon ビューの列幅を十分な大きさに設定し、アイテムどうしが
        '  重ならないようにします
        ' 2 番目と 3 番目の列は SmallIcon ビューに表示されないため、
        '  SmallIcon ビューでこれらの列を設定する必要はないことに注意してください
        lvColumnHeader.Width = 90

        ' 詳細ビューに変更し、SmallIcon ビューとは異なる、
        '  詳細ビュー用の適切な列幅を設定します
        SetView(View.Details)

        ' 最初の列は、詳細ビューでは SmallIcon ビューよりもわずかに大きくする必要があり、
        '  列2 および 列3 は、詳細ビューでは明示的なサイズを
        '  設定する必要があります
        lvColumnHeader.Width = 100

        lvColumnHeader = ListView.Columns.Add("列2")
        lvColumnHeader.Width = 70

        lvColumnHeader = ListView.Columns.Add("列3")
        lvColumnHeader.Width = 70

    End Sub

    Private Sub ExitToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ExitToolStripMenuItem.Click
        'このフォームを閉じます
        Me.Close()
    End Sub

    Private Sub ToolBarToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ToolBarToolStripMenuItem.Click
        'toolstrip の表示状態および関連メニュー項目のチェック状態を切り替えます
        ToolBarToolStripMenuItem.Checked = Not ToolBarToolStripMenuItem.Checked
        ToolStrip.Visible = ToolBarToolStripMenuItem.Checked
    End Sub

    Private Sub StatusBarToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles StatusBarToolStripMenuItem.Click
        'statusstrip の表示状態および関連メニュー項目のチェック状態を切り替えます
        StatusBarToolStripMenuItem.Checked = Not StatusBarToolStripMenuItem.Checked
        StatusStrip.Visible = StatusBarToolStripMenuItem.Checked
    End Sub

    'フォルダー ペインを表示するかどうかを変更します
    Private Sub ToggleFoldersVisible()
        '最初に、関連メニュー項目のチェック状態を切り替えます
        FoldersToolStripMenuItem.Checked = Not FoldersToolStripMenuItem.Checked

        '同期するフォルダーのツール バー ボタンを変更します
        FoldersToolStripButton.Checked = FoldersToolStripMenuItem.Checked

        ' TreeView を含むパネルを折りたたみます
        Me.SplitContainer.Panel1Collapsed = Not FoldersToolStripMenuItem.Checked
    End Sub

    Private Sub FoldersToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles FoldersToolStripMenuItem.Click
        ToggleFoldersVisible()
    End Sub

    Private Sub FoldersToolStripButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles FoldersToolStripButton.Click
        ToggleFoldersVisible()
    End Sub

    Private Sub SetView(ByVal View As System.Windows.Forms.View)
        'どのメニュー項目をチェックするかを設定します
        Dim MenuItemToCheck As ToolStripMenuItem = Nothing
        Select Case View
            Case View.Details
                MenuItemToCheck = DetailsToolStripMenuItem
            Case View.LargeIcon
                MenuItemToCheck = LargeIconsToolStripMenuItem
            Case View.List
                MenuItemToCheck = ListToolStripMenuItem
            Case View.SmallIcon
                MenuItemToCheck = SmallIconsToolStripMenuItem
            Case View.Tile
                MenuItemToCheck = TileToolStripMenuItem
            Case Else
                Debug.Fail("Unexpected View")
                View = View.Details
                MenuItemToCheck = DetailsToolStripMenuItem
        End Select

        '適切なメニュー項目をチェックし、[表示] メニューのその他の項目をすべて解除します
        For Each MenuItem As ToolStripMenuItem In ListViewToolStripButton.DropDownItems
            If MenuItem Is MenuItemToCheck Then
                MenuItem.Checked = True
            Else
                MenuItem.Checked = False
            End If
        Next

        '最後に、要求されたビューを設定します
        ListView.View = View
    End Sub

    Private Sub ListToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ListToolStripMenuItem.Click
        SetView(View.List)
    End Sub

    Private Sub DetailsToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles DetailsToolStripMenuItem.Click
        SetView(View.Details)
    End Sub

    Private Sub LargeIconsToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles LargeIconsToolStripMenuItem.Click
        SetView(View.LargeIcon)
    End Sub

    Private Sub SmallIconsToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles SmallIconsToolStripMenuItem.Click
        SetView(View.SmallIcon)
    End Sub

    Private Sub TileToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles TileToolStripMenuItem.Click
        SetView(View.Tile)
    End Sub

    Private Sub OpenToolStripMenuItem_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles OpenToolStripMenuItem.Click
        Dim OpenFileDialog As New OpenFileDialog
        OpenFileDialog.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        OpenFileDialog.Filter = "テキスト ファイル (*.txt)|*.txt"
        OpenFileDialog.ShowDialog(Me)

        Dim FileName As String = OpenFileDialog.FileName
        ' TODO: ファイルを開くコードを追加します
    End Sub

    Private Sub SaveAsToolStripMenuItem_Click(ByVal sender As Object, ByVal e As EventArgs) Handles SaveAsToolStripMenuItem.Click
        Dim SaveFileDialog As New SaveFileDialog
        SaveFileDialog.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        SaveFileDialog.Filter = "テキスト ファイル (*.txt)|*.txt"
        SaveFileDialog.ShowDialog(Me)

        Dim FileName As String = SaveFileDialog.FileName
        ' TODO: 現在のフォームの内容をファイルに保存するためのコードをここに追加します
    End Sub

    Private Sub TreeView_AfterSelect(ByVal sender As Object,
                                     ByVal e As TreeViewEventArgs) Handles TreeView.AfterSelect
        ' TODO: 現在選択されている treeview のノードに基づき listview の内容を変更するコードを追加します
        'LoadListView()
        Call LoadListView(e.Node.FullPath)
    End Sub

End Class
